package com.ether;

import org.apache.commons.lang.ArrayUtils;
import org.junit.Assert;
import org.junit.Test;
import sun.misc.BASE64Decoder;
import sun.misc.BASE64Encoder;

import java.io.FileInputStream;
import java.io.IOException;
import java.security.DigestException;
import java.security.NoSuchAlgorithmException;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashSet;
import java.util.List;
import java.util.Properties;
import java.util.Set;
import java.util.TimeZone;

/**
 * @author vmipsl
 * @date 2011
 */
public class OtherTest
{
    @Test
    public void testDatesMoisPlusUn()
            throws Exception
    {
        final DateFormat shortDateFormat = new SimpleDateFormat( "MMyyyy" );
        final DateFormat completDateFormat = new SimpleDateFormat( "dd-MM-yyyy" );
        final Date firstMois = shortDateFormat.parse( "102008" );
        final String firstMoisString = completDateFormat.format( firstMois );
        Assert.assertEquals( firstMoisString, "01-10-2008" );

        final Calendar calendar = Calendar.getInstance();
        calendar.setTime( firstMois );
        calendar.add( Calendar.MONTH, 1 );
        final Date secondMois = calendar.getTime();
        final String secondMoisString = completDateFormat.format( secondMois );
        Assert.assertEquals( secondMoisString, "01-11-2008" );
    }

    @Test
    public void testDates()
            throws Exception
    {
        List<Date> dates = new ArrayList<Date>();
        final DateFormat dateFormat = new SimpleDateFormat( "yyyy-MM-dd" );

        dates.add( dateFormat.parse( "2007-01-01" ) );
        dates.add( dateFormat.parse( "2007-01-02" ) );

        final DateFormat shortFormat = new SimpleDateFormat( "yyyy" );
        Set<String> shortDates = new HashSet<String>();
        for( final Date aDate : dates )
        {
            shortDates.add( shortFormat.format( aDate ) );
        }

        final Calendar cal = Calendar.getInstance();
        cal.setTimeInMillis( Long.valueOf( "1246811160000" ) );
        // 05/07/2009 18h26
        Date date = cal.getTime();

        cal.setTimeInMillis( Long.valueOf( "1246818360000" ) );
        // 05/07/2009 20h26
        date = cal.getTime();
    }

    /**
     * Test transform List<Pair> en Pair<List, List>
     * Method used in getListsByPlateformByParameterByPeriodForTimeSerie
     */
    @Test
    public void testListPairToPairLists()
    {
        final List<Object[]> objects = new ArrayList<Object[]>( 3 );
        final Object[] obj1 = new Object[2];
        obj1[0] = 2.2;
        obj1[1] = new Date();
        objects.add( obj1 );

        final Object[] obj2 = new Object[2];
        obj2[0] = 2.5;
        obj2[1] = new Date();
        objects.add( obj2 );

        final Object[] obj3 = new Object[2];
        obj3[0] = 2.7;
        obj3[1] = new Date();
        objects.add( obj3 );

        if( objects.get( 0 )[0] instanceof Double && objects.get( 0 )[1] instanceof Date )
        {
            final double[] firstValues = new double[objects.size()];
            final Date[] secondValues = new Date[objects.size()];
            int i = 0;
            for( final Object[] value : objects )
            {
                secondValues[i] = (Date) value[1];
                firstValues[i] = (Double) value[0];
                i++;
            }
            final Pair<double[], Date[]> values = new Pair( firstValues, secondValues );

            Assert.assertEquals( values.getFirstValue().length, objects.size() );
            Assert.assertEquals( values.getSecondValue().length, objects.size() );
            Assert.assertEquals( values.getFirstValue()[0], obj1[0] );
            Assert.assertEquals( values.getSecondValue()[0], obj1[1] );
            Assert.assertEquals( values.getFirstValue()[1], obj2[0] );
            Assert.assertEquals( values.getSecondValue()[1], obj2[1] );
            Assert.assertEquals( values.getFirstValue()[2], obj3[0] );
            Assert.assertEquals( values.getSecondValue()[2], obj3[1] );
        }
    }

    @Test
    public void testConversionListToArray()
    {
        final List<Double> doubleList = new ArrayList<Double>( 2 );
        doubleList.add( 1.2 );
        doubleList.add( 5.6 );

        Double[] doubleArray = new Double[doubleList.size()];
        doubleArray = doubleList.toArray( doubleArray );

        final double[] doubles = ArrayUtils.toPrimitive( doubleArray );
        Assert.assertEquals( doubles[0], (double) doubleList.get( 0 ), 0 );
        Assert.assertEquals( doubles[1], (double) doubleList.get( 1 ), 0 );

        double[] doubles1 = EtherHelper.convertListDoubleToDoubleArray( doubleList );
        Assert.assertEquals( doubles1[0], (double) doubleList.get( 0 ), 0 );
        Assert.assertEquals( doubles1[1], (double) doubleList.get( 1 ), 0 );
    }

    @Test
    public void testCreateValuesForTimeSerie()
    {
        final Integer size = 5;
        final Integer delta = 8;

        final double[] values = new double[size];
        final Date[] dates = new Date[size];
        final Calendar calCEST = Calendar.getInstance();
        final Date paf = calCEST.getTime();
        calCEST.setTimeInMillis( Long.valueOf( "1246811160000" ) );
        final Date dateCEST = calCEST.getTime();

        final Calendar calGMT = new GregorianCalendar( TimeZone.getTimeZone( "GMT" ) );
        final Date pif = calGMT.getTime();
        calGMT.setTimeInMillis( Long.valueOf( "1246811160000" ) );
        final Date dateGMT = calGMT.getTime();

        final Date date = new Date();
        final DateFormat cetFormat = new SimpleDateFormat();
        final DateFormat gmtFormat = new SimpleDateFormat();
        final TimeZone gmtTime = TimeZone.getTimeZone( "GMT" );
        final TimeZone cetTime = TimeZone.getTimeZone( "CET" );
        cetFormat.setTimeZone( gmtTime );
        gmtFormat.setTimeZone( cetTime );
        System.out.println( "GMT Time: " + cetFormat.format( date ) );
        System.out.println( "CET Time: " + gmtFormat.format( date ) );

        for( int i = 0; i < size; i++ )
        {
//            cal.add( Calendar.MINUTE, (int) ( 2 + i + ( Math.random() * 8 ) ) );
            calGMT.add( Calendar.MINUTE, (int) ( 2 * i ) );
            dates[i] = calGMT.getTime();
            values[i] = (double) i * Math.random() * delta;
        }

        final Data datas = new Data( values, dates );
    }

    @Test
    public void testEcnryptSHA1()
    {
        try
        {
            final String password = "boum";
            final byte[] sHAPassword = EtherHelper.encryptStringToHash( password );
            final String rePassword = EtherHelper.displayEncryptedHash( sHAPassword );

            final BASE64Decoder decoder = new BASE64Decoder();
            final byte[] base64Password = decoder.decodeBuffer( password );

            final BASE64Encoder endecoder = new BASE64Encoder();
            final String base64DecodedPassword = endecoder.encode( base64Password );

            final String tot = "tit";
        }
        catch( DigestException e )
        {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
        catch( NoSuchAlgorithmException e )
        {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
        catch( IOException e )
        {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
    }

    @Test
    public void testProperties()
    {
        try
        {
            final Properties prop = new Properties();
            prop.load( new FileInputStream( "/home_local/bob.properties" ) );
            final String path = prop.getProperty( "pif" );
            final FileInputStream fileInputStream = new FileInputStream( path + "/anytime.css" );
            final Integer fileSize = fileInputStream.read();
            Assert.assertEquals( fileSize, (Integer) 47 );
        }
        catch( IOException e )
        {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
    }

}